# BayesLDM

This repository contains the official implementation for the BayesLDM paper. 
This work is supported by National Institutes of Health through grants U01CA229445 and 1P41EB028242.
The paper was accepted at IEEE/ACM international conference on Connected Health: Applications, Systems and Engineering Technologies (CHASE) 2022. 

## Examples

See the [Examples](https://github.com/reml-lab/BayesLDM/tree/main/Examples) directory for a list of BayesLDM examples that can be run locally or launched in Google Colab.

For example:

+ [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/reml-lab/BayesLDM/blob/main/Examples/BayesLDM_quickstart.ipynb)  BayesLDM Quickstart

## Citing BayesLDM

If you use BayesLDM, please cite the paper:

  @inproceedings{BayesLDM2022,
    author = {Tung, Karine and De La Torre, Steven and El Mistiri, Mohamed and Braga De Braganca, Rebecca and Hekler, Eric and Pavel, Misha and Rivera, Daniel and Klasnja, Pedja and Spruijt-Metz, Donna and Marlin, Benjamin M.},
    title = {BayesLDM: A Domain-Specific Language for Probabilistic Modeling of Longitudinal Data},
    publisher = {arXiv},  
    year = {2022},
    doi = {10.48550/arxiv.2209.05581}
  }

This paper was accepted at IEEE/ACM international conference on Connected Health: Applications, Systems and Engineering Technologies (CHASE) 2022. The citation for CHASE 2022 is coming soon.
